@@ -9,9 +9,6 @@ def _connection(config):
     if config['db_type'] == 'mysql':
         return MysqlConnection(config)
 
-    if config['db_type'] == 'sqlite':
-        return SqliteConnection(config)
-
 
 class BaseBuilder():
 
@@ -21,6 +18,18 @@ class BaseBuilder():
     def __init__(self, *args, **kwargs):
         super().__init__()
 
+    @combomethod
+    def validate_type(self, item):
+        if isinstance(item, self.__class__):
+            return True
+        else:
+            try:
+                item = self(item)
+            except Exception as e:
+                raise TypeError(
+                    f'item must be or change to {self.__class__} type')
+            return True
+
     def _connection(self):
         config = self.__config__
 
@@ -29,6 +38,3 @@ class BaseBuilder():
 
         if config['db_type'] == 'mysql':
             return MysqlConnection(config)
-
-        if config['db_type'] == 'sqlite':
-            return SqliteConnection(config)
